@@ -1,16 +1,13 @@
 import collections
 import copy
-import logging
+import time
 import typing as tp
 
-logger = logging.getLogger(__name__)
 
-__all__ = [
-    'CallableGroup',
-]
+T = tp.TypeVar('T')
 
 
-class CallableGroup:
+class CallableGroup(tp.Generic[T]):
     """
     This behaves like a function, but allows to add other functions to call
     when invoked, eg.
@@ -36,11 +33,11 @@ class CallableGroup:
                                    silently ignored. If gather is set,
                                    result will be the exception instance
         """
-        self.callables = collections.OrderedDict()  # type: tp.Dict[tp.Callable, bool]
-        self.gather = gather  # type: bool
+        self.callables = collections.OrderedDict()    # type: tp.Dict[tp.Callable, bool]
+        self.gather = gather                          # type: bool
         self.swallow_exceptions = swallow_exceptions  # type: bool
 
-    def add(self, callable_: tp.Callable, one_shot: bool = False):
+    def add(self, callable_: tp.Callable[[], T], one_shot: bool = False):
         """
         :param callable_: callable
         :param one_shot: if True, callable will be unregistered after single call
@@ -51,7 +48,7 @@ class CallableGroup:
             return
         self.callables[callable_] = one_shot
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs) -> tp.Optional[tp.List[T]]:
         """
         Run the callable. All registered callables will be called with
         passed arguments, so they should have the same arity.
@@ -80,3 +77,24 @@ class CallableGroup:
 
         if self.gather:
             return results
+
+
+class CallNoOftenThan:
+    """
+    A class that will ensure that calls to given callable are made no sooner
+    than after some interval.
+
+    :param interval: interval in seconds
+    :param callable_: callable to call
+    """
+    __slots__ = ('interval', 'callable', 'last_called')
+
+    def __init__(self, interval: float, callable_: tp.Callable[[], None]):
+        self.interval = interval            # type: float
+        self.callable = callable_           # type: tp.Callable[[], None]
+        self.last_called = 0                # type: float
+
+    def __call__(self, *args, **kwargs):
+        if time.monotonic() - self.last_called >= self.interval:
+            self.callable(*args, **kwargs)
+            self.last_called = time.monotonic()
