@@ -14,6 +14,8 @@ class Condition(PythonCondition):
     A wrapper to faciliate easier usage of Pythons' threading.Condition.
 
     There's no need to acquire the underlying lock, as wait/notify/notify_all do it for you.
+
+    This happens to sorta not work on PyPy. Use at your own peril. You have been warned.
     """
 
     def wait(self, timeout: tp.Optional[float] = None):
@@ -21,7 +23,7 @@ class Condition(PythonCondition):
         Wait for condition to become true.
 
         :param timeout: timeout to wait. None is default and means infinity
-        :raises ResourceLocked: unable to acquire the lock within specified timeout.
+        :raises ResourceLocked: unable to acquire the underlying lock within specified timeout.
         :raises WouldWaitMore: wait's timeout has expired
         """
         with measure() as measurement:
@@ -82,7 +84,6 @@ class TerminableThread(threading.Thread):
     >>>     ...
     >>> self.assertFalse(a.is_alive())
     """
-    __slots__ = ('_terminating',)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
